@@ -396,31 +396,35 @@ loadprop (int i)
 {
   GkbKeymap *actdata;
   gchar *buf;
+  gchar *default_cmd;
 
   actdata = g_new0 (GkbKeymap, 1);
 
+
   buf = g_strdup_printf (_("name_%d"),i);
-  actdata->name = gkb_load_pref (buf, (i?"Hungarian 105 keys keyboard":"US 105 key keyboard"));
+  actdata->name = gkb_load_pref (buf, (i?"US 105 key keyboard":"Gnome Keyboard default"));
   g_free (buf);
 
   buf = g_strdup_printf (_("label_%d"), i);
-  actdata->label = gkb_load_pref (buf, (i?"hu":"us"));
+  actdata->label = gkb_load_pref (buf, (i?"us":"gkb"));
   g_free (buf);
   
   buf = g_strdup_printf (_("country_%d"), i);
-  actdata->country = gkb_load_pref (buf, (i?"Hungary":"United States"));
+  actdata->country = gkb_load_pref (buf, (i?"United States":"Gnome Keyboard"));
   g_free (buf);
   
   buf = g_strdup_printf (_("lang_%d"), i);
-  actdata->lang = gkb_load_pref (buf, (i?"Hungarian":"English"));
+  actdata->lang = gkb_load_pref (buf, (i?"English":"International"));
   g_free (buf);
   
   buf = g_strdup_printf (("flag_%d"), i);
-  actdata->flag = gkb_load_pref (buf, (i?"hu.png":"us.png"));
+  actdata->flag = gkb_load_pref (buf, (i?"us.png":"gkb.png"));
   g_free (buf);
   
   buf = g_strdup_printf (_("command_%d"), i);
-  actdata->command = gkb_load_pref (buf, (i?"gkb_xmmap hu":"gkb_xmmap us"));
+  default_cmd = g_strdup_printf ("xmodmap %s/.gkb_default.xmm", g_get_home_dir ()); 
+  actdata->command = gkb_load_pref (buf, (i?"gkb_xmmap us":default_cmd));
+  g_free (default_cmd);
   g_free(buf);
 
   actdata->pixbuf = NULL;
@@ -429,6 +433,27 @@ loadprop (int i)
   return actdata;
 }
 
+static void
+do_at_first_run (GKB * gkb) 
+{
+ gboolean firstrun;
+ gchar *cmd;
+ firstrun = gconf_applet_get_bool (PANEL_APPLET(gkb->applet), 
+                                      "first_run", NULL);
+ if ((firstrun == NULL) || (!firstrun)) {
+  cmd = g_strdup_printf ("echo \"! This file has generated by Gnome Keyboard applet\" > %s/.gkb_default.xmm", g_get_home_dir ());
+  system (cmd);
+  g_free (cmd);
+
+  cmd = g_strdup_printf ("xmodmap -pke >> %s/.gkb_default.xmm", g_get_home_dir ());
+  system (cmd);
+  g_free (cmd);
+
+  gconf_applet_set_bool (PANEL_APPLET (gkb->applet), "first_run", FALSE, NULL);
+ }
+ 
+}
+
 static void
 load_properties (GKB * gkb)
 {
@@ -441,6 +466,7 @@ load_properties (GKB * gkb)
   gkb->n = gconf_applet_get_int (PANEL_APPLET(gkb->applet), "num", NULL);
 
   gkb->key = gkb_load_pref ("key", "Mod1-Shift_L");
+
   convert_string_to_keysym_state (gkb->key, &gkb->keysym, &gkb->state);
 
   gkb->is_small = gconf_applet_get_bool (PANEL_APPLET(gkb->applet), "small", NULL);
@@ -604,7 +630,6 @@ about_cb (BonoboUIComponent *uic,
   	g_object_unref (pixbuf);
 
   gtk_window_set_wmclass (GTK_WINDOW (about), "keyboard layout switcher", "Keyboard Layout Switcher");
-  gnome_window_icon_set_from_file (GTK_WINDOW (about), GNOME_ICONDIR"/gkb.png");
   g_signal_connect (G_OBJECT(about), "destroy",
                           (GCallback)gtk_widget_destroyed, &about);
 
@@ -734,6 +759,13 @@ static const BonoboUIVerb gkb_menu_verbs [] = {
 };
 
 static void gkb_destroy (GtkWidget * widget, gpointer data) {
+	gchar *cmd;
+
+	/* restore the default keymap before exiting */
+	cmd = g_strdup_printf ("xmodmap %s/.gkb_default.xmm", g_get_home_dir ());
+	system (cmd);
+	g_free (cmd);
+
 	g_free(gkb);
 }
 
@@ -745,7 +777,9 @@ gboolean fill_gkb_applet(PanelApplet *applet)
   gkb->n = 0;
   gkb->cur = 0;
   gkb->applet = GTK_WIDGET (applet);
-
+  
+  gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gkb.png");
+  
   panel_applet_add_preferences (applet, "/schemas/apps/gkb-applet/prefs", NULL);
   /* FIXME: is bah_window needed for anything */
   bah_window = gtk_window_new (GTK_WINDOW_POPUP);
@@ -754,6 +788,8 @@ gboolean fill_gkb_applet(PanelApplet *applet)
 			    gdk_screen_height () + 1);
   gtk_widget_show (bah_window);
 
+  do_at_first_run(gkb);
+
   load_properties (gkb);
 
   gkb->keymap = g_list_nth_data (gkb->maps, 0);
