@@ -1,7 +1,7 @@
 #ifndef __GWEATHER_PREF_H_
 #define __GWEATHER_PREF_H_
 
-/* $Id: gweather-pref.h,v 1.5 2002/01/30 03:25:30 kevinv Exp $ */
+/* $Id: gweather-pref.h,v 1.6 2002/03/26 01:44:04 kevinv Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -23,6 +23,11 @@ extern void gweather_pref_run (GWeatherApplet *gw_applet);
 extern void gweather_pref_load (GWeatherApplet *gw_applet);
 extern void gweather_pref_save (const gchar *path, GWeatherApplet *gw_applet);
 
+void add_atk_relation (GtkWidget *widget1, GtkWidget *widget2, AtkRelationType type);
+void set_access_namedesc (GtkWidget *widget, const gchar *name, const gchar *desc);
+
+
+
 G_END_DECLS
 
 #endif /* __GWEATHER_PREF_H_ */
