@@ -189,7 +189,21 @@ static gint setup_done = FALSE;
 static void about_cb (BonoboUIComponent *uic, gpointer data, const gchar *verbname)
 {
 	static GtkWidget *about = NULL;
-	const gchar *authors[8];
+	GdkPixbuf 	 *pixbuf;
+	GError		 *error = NULL;
+	gchar		 *file;
+	
+	static const gchar *authors[] = {
+		"John Ellis <johne@bellatlantic.net>",
+		"Martin Baulig <martin@home-of-linux.org> - ISDN",
+		NULL
+	};
+
+	const gchar *documenters[] = {
+		NULL
+	};
+
+	const gchar *translator_credits = _("translator_credits");
 
 	if (about != NULL)
 	{
@@ -198,19 +212,29 @@ static void about_cb (BonoboUIComponent *uic, gpointer data, const gchar *verbna
 		return;
 	}
 
-	authors[0] = "John Ellis <johne@bellatlantic.net>";
-	authors[1] = "Martin Baulig <martin@home-of-linux.org> - ISDN";
-	authors[2] = NULL;
+	file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "gnome-modem.png", FALSE, NULL);
+	pixbuf = gdk_pixbuf_new_from_file (file, &error);
+	g_free (file);
+	
+	if (error) {
+		g_warning (G_STRLOC ": cannot open %s: %s", file, error->message);
+		g_error_free (error);
+	}
 
-        about = gnome_about_new ( _("Modem Lights Applet"), VERSION,
+        about = gnome_about_new ( _("Modem Lights"), VERSION,
 			"(C) 2000",
 			_("Released under the GNU general public license.\n"
 			"A modem status indicator and dialer.\n"
 			"Lights in order from the top or left are Send data and Receive data."),
 			authors,
-			NULL,
-			NULL,
-			NULL);
+			documenters,
+			strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+			pixbuf);
+
+	if (pixbuf)
+		gdk_pixbuf_unref (pixbuf);
+
+	gtk_window_set_wmclass (GTK_WINDOW (about), "modem lights", "Modem Lights");
 	gtk_signal_connect( GTK_OBJECT(about), "destroy",
 			    GTK_SIGNAL_FUNC(gtk_widget_destroyed), &about );
 	gtk_widget_show (about);
@@ -1373,27 +1397,30 @@ static void applet_change_pixel_size(PanelApplet *applet, gint size, gpointer da
         data = NULL;
 }
 
+/* This is a hack around the fact that gtk+ doesn't
+ * propogate button presses on button2/3.
+ */
+static gboolean
+button_press_hack (GtkWidget      *widget,
+                   GdkEventButton *event,
+                   GtkWidget      *applet)
+{
+    if (event->button == 3 || event->button == 2) {
+	event->window = applet->window;
+	gtk_main_do_event ((GdkEvent *) event);
+
+	return TRUE;
+    }
+
+    return FALSE;
+}
+
+
 static void show_help_cb(BonoboUIComponent *uic, gpointer data, const gchar *verbname)
 {
-#ifdef FIXME
-	static GnomeHelpMenuEntry help_entry = { NULL, "index.html"};
-
-	help_entry.name = gnome_app_id;
-    
-	gnome_help_display (NULL, &help_entry);
-#endif
+	gnome_help_display ("modemlights_applet", NULL, NULL);
 }
 
-#ifdef FIXME
-static gint applet_save_session(GtkWidget *widget, char *privcfgpath, char *globcfgpath)
-{
-	property_save(privcfgpath, FALSE);
-        return FALSE;
-        widget = NULL;
-        globcfgpath = NULL;
-}
-#endif
-
 static const BonoboUIVerb modem_applet_menu_verbs [] = {
         BONOBO_UI_VERB ("Props", property_show),
         BONOBO_UI_VERB ("Help", show_help_cb),
@@ -1416,6 +1443,8 @@ modemlights_applet_fill (PanelApplet *applet)
 
 	global_applet = GTK_WIDGET (applet);
 	
+	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-modem.png");
+	
 	panel_applet_add_preferences (applet, "/schemas/apps/modemlights/prefs", NULL);
 
 	for (i=0;i<119;i++)
@@ -1473,6 +1502,8 @@ modemlights_applet_fill (PanelApplet *applet)
 	gtk_widget_set_usize(button,5,5);
 	gtk_fixed_put(GTK_FIXED(frame),button,5,0);
 	gtk_signal_connect(GTK_OBJECT(button),"clicked",GTK_SIGNAL_FUNC(dial_cb),NULL);
+	g_signal_connect (G_OBJECT (button), "button_press_event",
+			  G_CALLBACK (button_press_hack), GTK_WIDGET (applet));
 	gtk_widget_show(button);
 
 	gtk_widget_realize(GTK_WIDGET (applet));
@@ -1537,7 +1568,7 @@ modemlights_applet_factory (PanelApplet *applet,
 
 PANEL_APPLET_BONOBO_FACTORY ("OAFIID:GNOME_ModemLightsApplet_Factory",
 			     PANEL_TYPE_APPLET,
-			     "Modemlights applet",
+			     "modemlights_applet",
 			     "0",
 			     modemlights_applet_factory,
 			     NULL)
